==> webkit2gtk_2.50.4.orig.tar.xz: webkitgtk-2.50.4/Source/JavaScriptCore/dfg/DFGCodeOriginPool.h <==
/*
 * Copyright (C) 2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(DFG_JIT)

#include "CallFrame.h"
#include "CodeOrigin.h"
#include <wtf/ThreadSafeRefCounted.h>

namespace JSC { namespace DFG {

class CodeOriginPool : public ThreadSafeRefCounted<CodeOriginPool> {
public:
    static Ref<CodeOriginPool> create()
    {
        return adoptRef(*new CodeOriginPool);
    }

    CallSiteIndex addCodeOrigin(CodeOrigin);
    CallSiteIndex addUniqueCallSiteIndex(CodeOrigin);
    CallSiteIndex lastCallSite() const;
    DisposableCallSiteIndex addDisposableCallSiteIndex(CodeOrigin);
    void removeDisposableCallSiteIndex(DisposableCallSiteIndex);
    void shrinkToFit();

    CodeOrigin get(unsigned index) { return m_codeOrigins[index]; }
    unsigned size() const { return m_codeOrigins.size(); }

private:
    CodeOriginPool();

    Vector<CodeOrigin, 0, UnsafeVectorOverflow> m_codeOrigins;
    Vector<unsigned> m_callSiteIndexFreeList;
};

} } // namespace JSC::DFG

#endif // ENABLE(DFG_JIT)

==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/JavaScriptCore/dfg/DFGCodeOriginPool.h <==
/*
 * Copyright (C) 2020 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(DFG_JIT)

#include <JavaScriptCore/CallFrame.h>
#include <JavaScriptCore/CodeOrigin.h>
#include <wtf/ThreadSafeRefCounted.h>

namespace JSC { namespace DFG {

class CodeOriginPool : public ThreadSafeRefCounted<CodeOriginPool> {
public:
    static Ref<CodeOriginPool> create()
    {
        return adoptRef(*new CodeOriginPool);
    }

    CallSiteIndex addCodeOrigin(CodeOrigin);
    CallSiteIndex addUniqueCallSiteIndex(CodeOrigin);
    CallSiteIndex lastCallSite() const;
    DisposableCallSiteIndex addDisposableCallSiteIndex(CodeOrigin);
    void removeDisposableCallSiteIndex(DisposableCallSiteIndex);
    void shrinkToFit();

    CodeOrigin get(unsigned index) { return m_codeOrigins[index]; }
    unsigned size() const { return m_codeOrigins.size(); }

private:
    CodeOriginPool();

    Vector<CodeOrigin, 0, UnsafeVectorOverflow> m_codeOrigins;
    Vector<unsigned> m_callSiteIndexFreeList;
};

} } // namespace JSC::DFG

#endif // ENABLE(DFG_JIT)
